.. raw:: html

	<p align="left">
	<img width=15% src="https://dai.lids.mit.edu/wp-content/uploads/2018/06/Logo_DAI_highres.png" alt=“DAI-Lab” />
	<i>An open source project from Data to AI Lab at MIT.</i>
	</p>

|Development Status| |PyPi Shield| |Run Tests Shield| |Downloads|


ml-stars
========

**Date**: |today| **Version**: |version|

-  License: `MIT <https://github.com/sintel-dev/ml-stars/blob/master/LICENSE>`__
-  Development Status:
   `Pre-Alpha <https://pypi.org/search/?c=Development+Status+%3A%3A+2+-+Pre-Alpha>`__
-  Homepage: https://github.com/sintel-dev/ml-stars
-  Documentation: https://sintel-dev.github.io/ml-stars

Overview
--------

Primitives and Pipelines for Time Series Data.

--------

.. |Development Status| image:: https://img.shields.io/badge/Development%20Status-2%20--%20Pre--Alpha-yellow
   :target: https://pypi.org/search/?c=Development+Status+%3A%3A+2+-+Pre-Alpha
.. |PyPi Shield| image:: https://img.shields.io/pypi/v/ml-stars.svg
   :target: https://pypi.python.org/pypi/ml-stars
.. |Run Tests Shield| image:: https://github.com/sintel-dev/ml-stars/workflows/Run%20Tests/badge.svg
   :target: https://github.com/sintel-dev/ml-stars/actions?query=workflow%3A%22Run+Tests%22+branch%3Amaster
.. |Downloads| image:: https://pepy.tech/badge/ml-stars
   :target: https://pepy.tech/project/ml-stars

.. toctree::
    :maxdepth: 3
    :hidden:
    :titlesonly:

    getting_started/index
    api_reference/index
    developer_guides/index
    Release Notes <history>
